OOIPY Documentation
===================
.. image:: ../../imgs/OOIPY_Logo.png
  :width: 200
  :alt: OOIPY Logo
  :align: right

OOIPY is a python toolbox designed to aid in scientific analysis
of Ocean Observatories Initiative (OOI) data. Some data (such as
broadband hydrophone data) is not available through the OOI API
(M2M). This package is designed to help with the acquiring of
datasets from the OOI Raw Data Server. Additionally, tools to
analyze the data, such as spectrogram and power spectral density
plotting are also provided.

First Steps
^^^^^^^^^^^
.. toctree::
    :maxdepth: 1

    install_instructions
    citation_guide
    usage_instructions


Modules Documentation
^^^^^^^^^^^^^^^^^^^^^
.. toctree::
   :maxdepth: 2

   hydrophone
   ctd
   request
   tools


